==> tcl8.3.0plus.tar.gz: tcl8.3.0/generic/tclStubLib.c <==
/* 
 * tclStubLib.c --
 *
 *	Stub object that will be statically linked into extensions that wish
 *	to access Tcl.
 *
 * Copyright (c) 1998-1999 by Scriptics Corporation.
 * Copyright (c) 1998 Paul Duffin.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * RCS: @(#) $Id: tclStubLib.c,v 1.4 1999/05/25 01:00:27 stanton Exp $
 */

#include "tclInt.h"
#include "tclPort.h"
#include "tclCompile.h"

TclStubs *tclStubsPtr = (TclStubs *) NULL;
TclPlatStubs *tclPlatStubsPtr = (TclPlatStubs *) NULL;
TclIntStubs *tclIntStubsPtr = (TclIntStubs *) NULL;
TclIntPlatStubs *tclIntPlatStubsPtr = (TclIntPlatStubs *) NULL;
TclCompileStubs *tclCompileStubsPtr = (TclCompileStubs *) NULL;


/*
 *----------------------------------------------------------------------
 *
 * Tcl_InitStubs --
 *
 *	Tries to initialise the stub table pointers and ensures that
 *	the correct version of Tcl is loaded.
 *
 * Results:
 *	The actual version of Tcl that satisfies the request, or
 *	NULL to indicate that an error occurred.
 *
 * Side effects:
 *	Sets the stub table pointers.
 *
 *----------------------------------------------------------------------
 */

#ifdef Tcl_InitStubs
#undef Tcl_InitStubs
#endif

char *
Tcl_InitStubs (interp, version, exact)
    Tcl_Interp *interp;
    char *version;
    int exact;
{
    Interp *iPtr = (Interp *) interp;
    char *actualVersion;

    if (!iPtr->stubTable || (iPtr->stubTable->magic != TCL_STUB_MAGIC)) {
	interp->result = "This interpreter does not support stubs-enabled extensions.";
	interp->freeProc = TCL_STATIC;
	return NULL;
    }
    tclStubsPtr = iPtr->stubTable;

    actualVersion = tclStubsPtr->tcl_PkgRequireEx(interp, "Tcl", version, exact,
	    (ClientData *) NULL);
    if (actualVersion == NULL) {
	tclStubsPtr = NULL;
	return NULL;
    }

    tclPlatStubsPtr = tclStubsPtr->hooks->tclPlatStubs;
    tclIntStubsPtr = tclStubsPtr->hooks->tclIntStubs;
    tclIntPlatStubsPtr = tclStubsPtr->hooks->tclIntPlatStubs;
    if (tclIntStubsPtr->tclFinalizeCondition) {
        tclCompileStubsPtr = tclStubsPtr->hooks->tclCompileStubs;
    }
    return actualVersion;
}

==> tcl8.3.1plus.tar.gz: tcl8.3.1/generic/tclStubLib.c <==
/* 
 * tclStubLib.c --
 *
 *	Stub object that will be statically linked into extensions that wish
 *	to access Tcl.
 *
 * Copyright (c) 1998-1999 by Scriptics Corporation.
 * Copyright (c) 1998 Paul Duffin.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * RCS: @(#) $Id: tclStubLib.c,v 1.4 1999/05/25 01:00:27 stanton Exp $
 */

#include "tclInt.h"
#include "tclPort.h"
#include "tclCompile.h"

TclStubs *tclStubsPtr = (TclStubs *) NULL;
TclPlatStubs *tclPlatStubsPtr = (TclPlatStubs *) NULL;
TclIntStubs *tclIntStubsPtr = (TclIntStubs *) NULL;
TclIntPlatStubs *tclIntPlatStubsPtr = (TclIntPlatStubs *) NULL;
TclCompileStubs *tclCompileStubsPtr = (TclCompileStubs *) NULL;


/*
 *----------------------------------------------------------------------
 *
 * Tcl_InitStubs --
 *
 *	Tries to initialise the stub table pointers and ensures that
 *	the correct version of Tcl is loaded.
 *
 * Results:
 *	The actual version of Tcl that satisfies the request, or
 *	NULL to indicate that an error occurred.
 *
 * Side effects:
 *	Sets the stub table pointers.
 *
 *----------------------------------------------------------------------
 */

#ifdef Tcl_InitStubs
#undef Tcl_InitStubs
#endif

char *
Tcl_InitStubs (interp, version, exact)
    Tcl_Interp *interp;
    char *version;
    int exact;
{
    Interp *iPtr = (Interp *) interp;
    char *actualVersion;

    if (!iPtr->stubTable || (iPtr->stubTable->magic != TCL_STUB_MAGIC)) {
	interp->result = "This interpreter does not support stubs-enabled extensions.";
	interp->freeProc = TCL_STATIC;
	return NULL;
    }
    tclStubsPtr = iPtr->stubTable;

    actualVersion = tclStubsPtr->tcl_PkgRequireEx(interp, "Tcl", version, exact,
	    (ClientData *) NULL);
    if (actualVersion == NULL) {
	tclStubsPtr = NULL;
	return NULL;
    }

    tclPlatStubsPtr = tclStubsPtr->hooks->tclPlatStubs;
    tclIntStubsPtr = tclStubsPtr->hooks->tclIntStubs;
    tclIntPlatStubsPtr = tclStubsPtr->hooks->tclIntPlatStubs;
    if (tclIntStubsPtr->tclDefaultEncodingDir_) {
        tclCompileStubsPtr = tclStubsPtr->hooks->tclCompileStubs;
    }
    return actualVersion;
}
